==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appsync/kotlin/outputs/FunctionSyncConfig.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appsync.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property conflictDetection Conflict Detection strategy to use. Valid values are `NONE` and `VERSION`.
 * @property conflictHandler Conflict Resolution strategy to perform in the event of a conflict. Valid values are `NONE`, `OPTIMISTIC_CONCURRENCY`, `AUTOMERGE`, and `LAMBDA`.
 * @property lambdaConflictHandlerConfig Lambda Conflict Handler Config when configuring `LAMBDA` as the Conflict Handler. See Lambda Conflict Handler Config.
 */
public data class FunctionSyncConfig(
    public val conflictDetection: String? = null,
    public val conflictHandler: String? = null,
    public val lambdaConflictHandlerConfig: FunctionSyncConfigLambdaConflictHandlerConfig? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appsync.outputs.FunctionSyncConfig):
            FunctionSyncConfig = FunctionSyncConfig(
            conflictDetection = javaType.conflictDetection().map({ args0 -> args0 }).orElse(null),
            conflictHandler = javaType.conflictHandler().map({ args0 -> args0 }).orElse(null),
            lambdaConflictHandlerConfig = javaType.lambdaConflictHandlerConfig().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appsync.kotlin.outputs.FunctionSyncConfigLambdaConflictHandlerConfig.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appsync/kotlin/outputs/FunctionSyncConfig.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appsync.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property conflictDetection Conflict Detection strategy to use. Valid values are `NONE` and `VERSION`.
 * @property conflictHandler Conflict Resolution strategy to perform in the event of a conflict. Valid values are `NONE`, `OPTIMISTIC_CONCURRENCY`, `AUTOMERGE`, and `LAMBDA`.
 * @property lambdaConflictHandlerConfig Lambda Conflict Handler Config when configuring `LAMBDA` as the Conflict Handler. See `lambda_conflict_handler_config` Block for details.
 */
public data class FunctionSyncConfig(
    public val conflictDetection: String? = null,
    public val conflictHandler: String? = null,
    public val lambdaConflictHandlerConfig: FunctionSyncConfigLambdaConflictHandlerConfig? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appsync.outputs.FunctionSyncConfig): FunctionSyncConfig = FunctionSyncConfig(
            conflictDetection = javaType.conflictDetection().map({ args0 -> args0 }).orElse(null),
            conflictHandler = javaType.conflictHandler().map({ args0 -> args0 }).orElse(null),
            lambdaConflictHandlerConfig = javaType.lambdaConflictHandlerConfig().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appsync.kotlin.outputs.FunctionSyncConfigLambdaConflictHandlerConfig.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}
